<?php

namespace Drupal\email_change_verification\Event;

use Drupal\Component\EventDispatcher\Event;
use Drupal\user\UserInterface;

/**
 * Allow developers to set the redirect destination.
 *
 * This event alters the passed-in route variables instead of returning a
 * RedirectResponse or similar object because those currently get fired
 * immediately if returned by an event.
 */
class EmailChangeVerificationSetRedirect extends Event {

  /**
   * The user account for which this change is being made.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * The route name of the redirect to be set.
   *
   * @var string
   */
  protected $route_name;

  /**
   * The parameters required by the route to be set.
   *
   * @var array
   */
  protected $route_parameters;

  /**
   * Any additional options to accompany the route.
   *
   * @var array
   */
  protected $options;

  /**
   * EmailChangeVerificationSetRedirect constructor.
   *
   * @param string $route_name
   * @param array $route_parameters
   * @param array $options
   */
  public function __construct(UserInterface $account, string $route_name, array $route_parameters = [], array $options = []) {
    $this->account = $account;
    $this->route_name = $route_name;
    $this->route_parameters = $route_parameters;
    $this->options = $options;
  }

  /**
   * @return \Drupal\user\UserInterface
   */
  public function getAccount(): UserInterface {
    return $this->account;
  }

  /**
   * @param $route_name
   */
  public function setRouteName(string $route_name): void {
    $this->route_name = $route_name;
  }

  /**
   * @return string
   */
  public function getRouteName(): string {
    return $this->route_name;
  }

  /**
   * @param $route_parameters
   */
  public function setRouteParameters(array $route_parameters): void {
    $this->route_parameters = $route_parameters;
  }

  /**
   * @return array
   */
  public function getRouteParameters(): array {
    return $this->route_parameters;
  }

  /**
   * @param $options
   */
  public function setOptions(array $options): void {
    $this->options = $options;
  }

  /**
   * @return array
   */
  public function getOptions(): array {
    return $this->options;
  }

}
